@@ -1,3 +1,71 @@
+# wrapper around the new function find_droughts() including pooling
+# just emulates the interface of the old and buggy function streamdef()
+streamdefRcmdr <- function(lfobj,
+                           pooling = c("none", "MA", "IT", "IC"),
+                           threslevel = 70,
+                           thresbreaks = c("fixed", "monthly", "daily","seasonal"),
+                           breakdays = c("01/06","01/10"),
+                           MAdays = 7,
+                           tmin = 5,
+                           IClevel = 0.1,
+                           mindur = 0,
+                           minvol = 0,
+                           table = c("all", "volmax", "durmax"),
+                           na.rm = TRUE,
+                           plot = TRUE
+) {
+
+  pooling <- match.arg(pooling)
+  thresbreaks <- match.arg(thresbreaks)
+  table <- match.arg(table, several.ok = FALSE)
+
+  breakdays <- paste(breakdays, "2000", sep = "/")
+  breakdays <- as.Date(breakdays, format = "%d/%m/%Y")
+
+  if(thresbreaks == "fixed") thresbreaks <- "constant"
+  if(thresbreaks == "seasonal") {
+    thresbreaks <- breakdays
+  }
+
+  x <- as.xts(lfobj)
+
+  threshold <- vary_threshold(x = x, varying = thresbreaks,
+                              fun = quantile, probs = (1 - threslevel/100),
+                              na.rm = na.rm)
+
+  # MA "pooling" can introduce NAs, do not warn twice
+  if(pooling == "MA") {
+    x <- suppressWarnings(find_droughts(x, threshold = threshold))
+  } else {
+    x <- find_droughts(x, threshold = threshold)
+  }
+
+  if(pooling == "MA") x <- pool_ma(x, n = MAdays)
+  if(pooling == "IT") x <- pool_ic(x, tmin = tmin, ratio = Inf)
+  if(pooling == "IC") x <- pool_ic(x, tmin = tmin, ratio = IClevel)
+
+  y <- summary(x, drop_minor = c(volume = minvol, duration = mindur))
+
+
+
+  if(table != "all") {
+    table <- c("volmax" = "volume", "durmax" = "duration")[table]
+    y$hyear <- water_year(y$start, hyear_start(lfobj))
+    y <- by(y, y$hyear, function(x) x[which.max(x[, table]), ])
+    y <- do.call(rbind, y)
+    rownames(y) <- NULL
+  }
+
+  if(plot) {
+    x$event.no[!x$event.no %in% y$event.no] <- 0
+    p <- plot(x, drop_minor = c(volume = minvol, duration = mindur))
+    print(p)
+  }
+
+  return(y)
+}
+
+
 # wrapper around the new function find_droughts() including pooling
 # just emulates the interface of the old and buggy function streamdef()
 streamdef <- function(lfobj,
@@ -14,7 +82,7 @@ streamdef <- function(lfobj,
                       na.rm = TRUE
 ) {
 
-  message("This is a wrapper around the new function 'find_droughts()' including pooling. Please use 'find_droughts()' directly, as in future versions 'streamdef' will be removed.")
+  message("This is a wrapper around the new function 'find_droughts()' including pooling. Please use 'find_droughts()' directly, as in future versions 'streamdef' will be removed.", domain = NA)
 
   pooling <- match.arg(pooling)
   thresbreaks <- match.arg(thresbreaks)
@@ -34,7 +102,13 @@ streamdef <- function(lfobj,
                               fun = quantile, probs = (1 - threslevel/100),
                               na.rm = na.rm)
 
-  x <- find_droughts(x, threshold = threshold)
+  # MA "pooling" can introduce NAs, do not warn twice
+  if(pooling == "MA") {
+    x <- suppressWarnings(find_droughts(x, threshold = threshold))
+  } else {
+    x <- find_droughts(x, threshold = threshold)
+  }
+
 
   if(pooling == "MA") x <- pool_ma(x, n = MAdays)
   if(pooling == "IT") x <- pool_ic(x, tmin = tmin, ratio = Inf)
